@@ -77,7 +77,7 @@ impl Selection<'_> {
     ) -> Result<CmdResult, ProgramError> {
         Ok(if self.is_exe {
             let path = self.path.to_string_lossy().to_string();
-            if let Some(export_path) = &con.launch_args.cmd_export_path {
+            if let Some(export_path) = &con.launch_args.outcmd {
                 // broot was launched as br, we can launch the executable from the shell
                 let f = OpenOptions::new().append(true).open(export_path)?;
                 writeln!(&f, "{}", path)?;
@@ -124,4 +124,25 @@ impl<'a> SelInfo<'a> {
             _ => None,
         }
     }
+    pub fn extension(&self) -> Option<&str> {
+        match self {
+            SelInfo::None => None,
+            SelInfo::One(sel) => sel.path.extension().and_then(|e| e.to_str()),
+            SelInfo::More(stage) => {
+                let common_extension = stage.paths()[0]
+                    .extension().and_then(|e| e.to_str());
+                #[allow(clippy::question_mark)]
+                if common_extension.is_none() {
+                    return None;
+                }
+                for path in stage.paths().iter().skip(1) {
+                    let extension = path.extension().and_then(|e| e.to_str());
+                    if extension != common_extension {
+                        return None;
+                    }
+                }
+                common_extension
+            }
+        }
+    }
 }
